 /*
  * Copyright (C), 2018-2022
  * Project: starterBI
  * FileName: OutputExcelPlus
  * Author:   xx
  * Date:     2022/11/15 21:26
  */
 package com.fr.plugin.akfgp.format;

 import com.fanruan.api.log.LogKit;
 import com.fr.intelli.record.Focus;
 import com.fr.intelli.record.Original;
 import com.fr.io.TemplateWorkBookIO;
 import com.fr.io.exporter.PageExcelExporter;
 import com.fr.main.TemplateWorkBook;
 import com.fr.main.workbook.PageWorkBook;
 import com.fr.main.workbook.ResultWorkBook;
 import com.fr.record.analyzer.EnableMetrics;
 import com.fr.report.core.ReportUtils;
 import com.fr.report.report.PageReport;
 import com.fr.schedule.extension.report.job.output.OutputExcel;
 import com.fr.stable.PageActor;
 import com.fr.stable.fun.Authorize;
 import com.fr.web.core.SessionPoolManager;
 import com.fr.web.core.TemplateSessionIDInfo;

 import java.io.OutputStream;
 import java.util.Map;

 import static com.fr.plugin.akfgp.format.OutputExcelPlus.PLUGIN_ID;

 /**
  * <Function Description><br>
  * <OutputExcelPlus>
  *
  * @author xx
  * @since 1.0.0
  */
 @EnableMetrics
 @Authorize(callSignKey = PLUGIN_ID)
 public class OutputExcelPlus extends OutputExcel {
     public static final String PLUGIN_ID = "com.fr.plugin.akfgp.job";
     public static final int CONVERT_TO_EXCEL_PLUS = 4096;
     public static final String SESSIONID = "SESSIONID";

     public OutputExcelPlus() {
     }

     @Override
     public int getFormat() {
         return CONVERT_TO_EXCEL_PLUS;
     }

     @Override
     public String getFileSuffix() {
         return ".xlsx";
     }

     @Override
     @Focus(id = PLUGIN_ID, text = "Plugin-akfgp", source = Original.PLUGIN)
     public void flush(OutputStream out, ResultWorkBook result) throws Exception {
         LogKit.info("akfgp-OutputExcelPlus output start ...");
         try {
             //定时调度配置的参数
             Map<String, Object> parameterMap = result.getExecuteParameters();
             String sheetParamName = parameterMap.get("paramName").toString();
             String sheetParamValue;
             if (parameterMap.containsKey("paramValue")) {
                 sheetParamValue = parameterMap.get("paramValue").toString();
             } else {
                 sheetParamValue = parameterMap.get(sheetParamName).toString();
             }
             String[] sheetParams = sheetParamValue.split(",");
             String sessionID = parameterMap.get(SESSIONID).toString();
             TemplateSessionIDInfo sessionIDInfo = SessionPoolManager.getSessionIDInfor(sessionID, TemplateSessionIDInfo.class);
             String tplPath = sessionIDInfo.getRelativePath();
             TemplateWorkBook workbook = TemplateWorkBookIO.readTemplateWorkBook(tplPath);
             result.removeReport(0);
             for (String sheetParam : sheetParams) {
                 parameterMap.put(sheetParamName, sheetParam);
                 PageWorkBook pageWorkBook = (PageWorkBook) workbook.execute(parameterMap, new PageActor());
                 PageReport pageReport = pageWorkBook.getPageReport(0);
                 result.addReport(sheetParam, pageReport);
             }
             PageExcelExporter excelExport = new PageExcelExporter(ReportUtils.getPaperSettingListFromWorkBook(result));
             excelExport.export(out, result);
             out.close();
         } catch (Exception e) {
             LogKit.error(e.getMessage(), e);
         }
     }
 }